<?php
/*
	SHChat
	by Scripthosting.net
	http://www.shchat.net

	Autor: Jan-Michael Fuhrmann
	info@scripthosting.net
*/

class Chat
{
	const CHAT_VERSION = "00901";

	
	/**
	* Bereinigt Strings
   	* @param string $string Zeichenkette
	* @return string
	*/
	public function clean( $string ){
		
		$string = trim($string);
		$string = str_replace("<","",$string);
		$string = str_replace(">","",$string);
		$string = str_replace("&","&amp;",$string);
		$string = urldecode($string);
		$string = ( !get_magic_quotes_gpc() ) ? addslashes($string) : $string;
		return $string;
	}
	
	
	/**
	 * Sends an AJAX request 
	 * @param $url
	 * @param $element
	 * @param $zeit
	 * @param $scroll
	 * @return String
	 */
	public static function ajax_refresh($url,$element,$zeit=5000,$scroll=1)	{
		return '<script type="text/javascript"> var '.$element.'1 = setInterval("macheRequest(\''. $url .'\',\''. $element .'\', '. $scroll .')",'. $zeit .'); </script>';
	}
	
	
	/**
	 * Clears an AJAX request
	 * @param $element 
	 * @return String
	 */
	public static function ajax_clear($element)	{
		return '<script type="text/javascript"> clearInterval('.$element.'1); </script>';
	}
	

	/** 
	 * Sends a self refresh request
	 * @param $url
	 * @param $zeit
	 * @return String
	 */
	public static function self_refresh($url,$zeit,$target){	
		return "<script type=\"text/javascript\"> setTimeout(\"window.open('{$url}','{$target}');\",{$zeit}); </script>";
	}
	
	
	/**
	 * Returns a String with all smileys 
	 * @return String
	 */
	public function getChatColors( $usercolor = "#000000", $lang = "" ){
		
		global $config;
		$lang = ( $lang == "" ) ? $config["language"] : $lang;
		$color_ini = $config["basepath"] . "/include/{$config["template_name"]}/lang/{$lang}/chatcolors.ini";
		$colors = "";
		
		$open = file($color_ini);
		
		foreach( $open as $value ){
			
			$get = explode("|",$value);
			$color_name = trim($get[0]);
			$color_code = trim($get[1]);

			$colors .= "<option";
			if( $usercolor == $color_code ) $colors .= " selected=\"selected\"";
			$colors .= " value=\"{$color_code}\" style=\"color: {$color_code}\">{$color_name}</option>" . "\r\n";
		}
		return $colors;
	}
	
	
	/**
	 * Returns a String with all smileys
	 * @param int $limit 
	 * @return String
	 */
	public function getSmileys( $limit = 0 ){
		
		global $config;
		$smiley_ini = $config["basepath"] . "/system/smileys/smileys.ini";
		$smiley_uri = $config["scriptpath"] . "/system/smileys/";
		$output = "";
		$i=0;
		
		$open = file($smiley_ini);
		
		foreach( $open as $value ){
			
			$get = explode("|",$value);
			$filename = trim($get[0]);
			$command = trim($get[1]);

			$output .= "<a href=\"javascript:setsmiley('{$command}');\"><img src=\"{$smiley_uri}{$filename}\" border=\"0\" alt=\"smiley\" /></a> " . "\r\n";
			$i++;
			
			if( $limit > 0 && $i >= $limit ){
				break;
			}
		}
		return $output;
	}
	
	
	/**
	 * Converts a string into smileys
	 * @param $string
	 * @return String
	 */
	public function convertSmileys( $string ){
		
		global $config;
		$smiley_ini = $config["basepath"] . "/system/smileys/smileys.ini";
		$smiley_uri = "system/smileys/";

		$open = file($smiley_ini);
		
		foreach( $open as $value ){
			
			$get = explode("|",$value);
			$count = count($get);
			$filename = trim($get[0]);
			
			for($i=1; $i < $count; $i++){
				$string = str_replace($get[$i],"<img src=\"{$smiley_uri}{$filename}\" alt=\"Smiley\" />",$string);				
			}
		}
		return $string;
	}
	
	
	/**
	 * Converts an uri string into an url
	 * @param $string
	 * @return String
	 */
	public function convertUrl( $string ){
		
		//$string = str_replace("&am p;","&",$string);
		//$string = str_replace("&a mp;","&",$string);
		//$string = str_replace("&amp ;","&",$string);
		//$string = str_replace("& amp;","&",$string);
		//$string = str_replace(" ","",$string);
		$get = explode(" ",$string);

		for($i=0; $i<count($get);$i++ ){
			
			if( substr($get[$i],0,7) == "http://" ){
				$url = ( strlen($get[$i]) > 50 ) ? substr($get[$i],0,40) . "...". substr($get[$i],-10) : $get[$i];
				$get[$i] = "<a href=\"{$get[$i]}\" target=\"_blank\">{$url}</a>";
			}
			elseif( substr($get[$i],0,4) == "www." ){
				$url = ( strlen($get[$i]) > 50 ) ? substr($get[$i],0,40) . "...". substr($get[$i],-10) : $get[$i];
				$get[$i] = "<a href=\"http://{$get[$i]}\" target=\"_blank\">{$url}</a>";
			}				
		}
		return implode(" ",$get);		
	}
	
	
	/**
	 * Returns a language object
	 * @param String $lang
	 * @return String[]
	 */
	public function getLanguage( $lang = "" ){
		
		global $config;
		
		$lang = ( $lang == "" ) ? $config["language"] : $lang;
		$res = @parse_ini_file("include/".$config["template_name"] . "/lang/{$lang}/global.ini",true);
		
		if($res != null){
			foreach( $res as $key => $value ){
				foreach( $value as $key0 => $value0 ){
						$res[$key][$key0] = str_replace("{overall_title}",$config["overall_title"],$res[$key][$key0]);
				}
			}
			return $res;		
		}
		else{
			return "404: Ini File not Found";
		}		
	}
	
	
	/**
	 * Returns the Online Users in the Chat
	 * @return int
	 */
	public function getAllOnlineUsers(){
		
		global $db;
		$result = $this->result("SELECT count(*) as anzahl FROM {$db["online"]} LIMIT 1");
		$row = $result->fetch_assoc();

		return (int)$row["anzahl"];
	}
}
?>